# Title

## SubTitle

__content__

## サブタイトル

[A link to GitHub](http://github.com/)

This is `$E = mc^2$` inline math.

This first math `$x^2$` in this line will render. This one `$z^3$` should as well.

Also within parentheses (`$x^2$`) and (`$z^3$`).

```mermaid
graph TD;
    A-->B;
    A-->C;
    B-->D;
    C-->D;
```
